@@ -1,11 +1,12 @@
 package LWP::ConsoleLogger::Everywhere;
-our $VERSION = '0.000040';
+our $VERSION = '0.000041';
 use strict;
 use warnings;
 
 use LWP::ConsoleLogger::Easy qw( debug_ua );
 use LWP::UserAgent;
 use Class::Method::Modifiers ();
+use Module::Runtime qw( require_module );
 
 no warnings 'once';
 
@@ -25,6 +26,22 @@ Class::Method::Modifiers::install_modifier(
     }
 );
 
+if ( require_module('Mojo::UserAgent') ) {
+    Class::Method::Modifiers::install_modifier(
+        'Mojo::UserAgent',
+        'around',
+        'new' => sub {
+            my $orig = shift;
+            my $self = shift;
+
+            my $ua = $self->$orig(@_);
+            push @{$loggers}, debug_ua($ua);
+
+            return $ua;
+        }
+    );
+}
+
 sub loggers {
     return $loggers;
 }
@@ -52,7 +69,7 @@ LWP::ConsoleLogger::Everywhere - LWP tracing everywhere
 
 =head1 VERSION
 
-version 0.000040
+version 0.000041
 
 =head1 SYNOPSIS
 
@@ -76,7 +93,7 @@ version 0.000040
 
 =head1 DESCRIPTION
 
-This module turns on L<LWP::ConsoleLogger::Easy> debugging for every L<LWP::UserAgent>
+This module turns on L<LWP::ConsoleLogger::Easy> debugging for every L<LWP::UserAgent> or L<Mojo::UserAgent>
 based user agent anywhere in your code. It doesn't matter what package or class it is in,
 or if you have access to the object itself. All you need to do is C<use> this module
 anywhere in your code and it will work.
